async function load_categories() {
  const response = await fetch('api_categories.php')
  const categories = await response.json()

  const section = document.querySelector('#categories')
  section.innerHTML = ''

  const ul = document.createElement('ul')
  section.appendChild(ul)

  for (category of categories) {
    const li = document.createElement('li')
    ul.appendChild(li)

    const a = document.createElement('a')
    a.textContent = category.name
    a.href = `#category/${category.id}`
    li.appendChild(a)
  }
}

async function load_articles() {
  const response = await fetch('api_articles.php')
  const articles = await response.json()

  const section = document.querySelector('#articles')
  section.innerHTML = ''

  for (article of articles) append_article(article, true)
}

async function load_category(id) {
  const response = await fetch(`api_category_articles.php?id=${id}`)
  const articles = await response.json()

  const section = document.querySelector('#articles')
  section.innerHTML = ''

  for (article of articles) append_article(article, true)
}

async function load_article(id) {
  const response = await fetch(`api_article.php?id=${id}`)
  const article = await response.json()

  const section = document.querySelector('#articles')
  section.innerHTML = ''

  append_article(article)
}

function append_article(article, excerpt = false) {
  const section = document.querySelector('#articles')

  const element = document.createElement('article')
  section.append(element)

  const header = document.createElement('header')
  element.appendChild(header)
  
  const h2 = document.createElement('h2')
  h2.textContent = article.title
  header.appendChild(h2)

  const h3 = document.createElement('h3')
  h3.textContent = `#${article.name}`
  header.appendChild(h3)

  const p = document.createElement('p')
  element.appendChild(p)

  if (excerpt) {
    p.textContent = `${article.body.split(' ').slice(0, 10).join(' ')}... `
    const a = document.createElement('a')
    a.textContent = '[Read More]'
    a.href = `#article/${article.id}`
    p.appendChild(a)
  } else {
    p.textContent = article.body
  }

  const footer = document.createElement('footer')
  const date = new Date(article.published*1000)
  footer.innerHTML = `<p>Written by ${article.author} on ${date.toLocaleDateString()} ${date.toLocaleTimeString()}</p>`
  element.appendChild(footer)
}

function parse_fragment() {
  const hash = window.location.hash

  if (hash) {
    const category = /#category\/(\d+)/.exec(hash)
    if (category) return load_category(category[1])

    const article = /#article\/(\d+)/.exec(hash)
    if (article) return load_article(article[1])
  } 

  load_articles()    
}

load_categories()
parse_fragment()

window.addEventListener('hashchange', parse_fragment)